@@ -1,10 +1,11 @@
-import requests
 import gzip
-import shutil
 import multiprocessing
+import requests
+import shutil
 
-from typing import Literal
 from pathlib import Path
+from typing import Literal
+
 
 HOME = Path.home()
 
@@ -41,26 +42,25 @@ def wkhtmltopdf_bin(
 
     filename = f"wkhtmltopdf_{version}.gz"
     url = f"{REPO}/blob/master/bin/{filename}?raw=true"
-    gz_path = HOME / filename
+
+    proc_id = multiprocessing.current_process().pid
+    # Allow to avoid conflict if launch from multiple source/workers
+    gz_path = HOME / f"{proc_id}_{filename}"
     bin_path = final_path / final_name
 
     r = requests.get(url, stream=True)
-    th_id = multiprocessing.current_process()
-    print("========================================== 0 ", th_id)
-    with multiprocessing.Lock():
-        print("========================================== 1 ", th_id)
-        with open(gz_path, "wb") as f:
-            for chunk in r.iter_content(chunk_size=1024):
-                if chunk:
-                    f.write(chunk)
-            print("========================================== 2 ", th_id)
-            with gzip.open(HOME / filename, "rb") as f_in:
-                with open(bin_path, "wb") as f_out:
-                    shutil.copyfileobj(f_in, f_out)
-            print("========================================== 3 ", th_id)
-            gz_path.unlink()
 
-    print("========================================== 4 ", th_id)
+    with open(gz_path, "wb") as f:
+        for chunk in r.iter_content(chunk_size=1024):
+            if chunk:
+                f.write(chunk)
+
+    with gzip.open(gz_path, "rb") as f_in:
+        with open(bin_path, "wb") as f_out:
+            shutil.copyfileobj(f_in, f_out)
+
+    gz_path.unlink()
+
     return str(bin_path)
 
 
